==> gcc-7_7.5.0.orig.tar.gz: gcc-7.5.0/libstdc++-v3/testsuite/experimental/optional/nullopt.cc <==
// { dg-do run { target c++14 } }

// Copyright (C) 2013-2017 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.

#include <experimental/optional>
#include <testsuite_hooks.h>

int main()
{
  // [20.5.6] Disengaged state indicator
  static_assert( std::is_same<decltype(std::experimental::nullopt), const std::experimental::nullopt_t>(), "" );
  static_assert( std::is_empty<std::experimental::nullopt_t>(), "" );
  static_assert( std::is_literal_type<std::experimental::nullopt_t>(), "" );
  static_assert( !std::is_default_constructible<std::experimental::nullopt_t>(), "" );

  {
    std::experimental::optional<int> o = std::experimental::nullopt;
    VERIFY( !o );
  }

  {
    std::experimental::optional<int> o = { std::experimental::nullopt };
    VERIFY( !o );
  }

  {
    std::experimental::optional<int> o { std::experimental::nullopt };
    VERIFY( !o );
  }
}

==> gcc-11_11.4.0.orig.tar.gz: gcc-11.4.0/libstdc++-v3/testsuite/experimental/optional/nullopt.cc <==
// { dg-do run { target c++14 } }

// Copyright (C) 2013-2021 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.

#include <experimental/optional>
#include <testsuite_hooks.h>

int main()
{
  // [20.5.6] Disengaged state indicator
  static_assert( std::is_same<decltype(std::experimental::nullopt), const std::experimental::nullopt_t>(), "" );
  static_assert( std::is_empty<std::experimental::nullopt_t>(), "" );
  static_assert( __is_literal_type(std::experimental::nullopt_t), "" );
  static_assert( !std::is_default_constructible<std::experimental::nullopt_t>(), "" );

  {
    std::experimental::optional<int> o = std::experimental::nullopt;
    VERIFY( !o );
  }

  {
    std::experimental::optional<int> o = { std::experimental::nullopt };
    VERIFY( !o );
  }

  {
    std::experimental::optional<int> o { std::experimental::nullopt };
    VERIFY( !o );
  }
}
